@@ -2,7 +2,9 @@ package internal
 
 import (
 	"net/http/httptest"
+	"net/url"
 	"testing"
+	"time"
 
 	"github.com/go-acme/lego/v4/platform/tester/servermock"
 	"github.com/stretchr/testify/assert"
@@ -11,15 +13,17 @@ import (
 
 func setupClient(server *httptest.Server) (*Client, error) {
 	client := NewClient("user")
-	client.baseURL = server.URL
+	client.BaseURL, _ = url.Parse(server.URL)
 	client.HTTPClient = server.Client()
 
+	client.maxElapsedTime = 1 * time.Second
+
 	return client, nil
 }
 
 func TestClient_GetDNSSettings(t *testing.T) {
 	client := servermock.NewBuilder[*Client](setupClient).
-		Route("POST /", servermock.ResponseFromFixture("get_dns_settings.xml"),
+		Route("POST /KasApi.php", servermock.ResponseFromFixture("get_dns_settings.xml"),
 			servermock.CheckRequestBodyFromFixture("get_dns_settings-request.xml").
 				IgnoreWhitespace()).
 		Build(t)
@@ -96,9 +100,24 @@ func TestClient_GetDNSSettings(t *testing.T) {
 	assert.Equal(t, expected, records)
 }
 
+func TestClient_GetDNSSettings_error_flood_protection(t *testing.T) {
+	client := servermock.NewBuilder[*Client](setupClient).
+		Route("POST /KasApi.php",
+			servermock.ResponseFromFixture("flood_protection.xml"),
+		).
+		Build(t)
+
+	assert.Zero(t, client.floodTime)
+
+	_, err := client.GetDNSSettings(mockContext(t), "example.com", "")
+	require.EqualError(t, err, "KasApi: SOAP-ENV:Server: flood_protection: 0.0688529014587")
+
+	assert.NotZero(t, client.floodTime)
+}
+
 func TestClient_AddDNSSettings(t *testing.T) {
 	client := servermock.NewBuilder[*Client](setupClient).
-		Route("POST /", servermock.ResponseFromFixture("add_dns_settings.xml"),
+		Route("POST /KasApi.php", servermock.ResponseFromFixture("add_dns_settings.xml"),
 			servermock.CheckRequestBodyFromFixture("add_dns_settings-request.xml").
 				IgnoreWhitespace()).
 		Build(t)
@@ -118,7 +137,7 @@ func TestClient_AddDNSSettings(t *testing.T) {
 
 func TestClient_DeleteDNSSettings(t *testing.T) {
 	client := servermock.NewBuilder[*Client](setupClient).
-		Route("POST /", servermock.ResponseFromFixture("delete_dns_settings.xml"),
+		Route("POST /KasApi.php", servermock.ResponseFromFixture("delete_dns_settings.xml"),
 			servermock.CheckRequestBodyFromFixture("delete_dns_settings-request.xml").
 				IgnoreWhitespace()).
 		Build(t)
