@@ -3,6 +3,7 @@ package internal
 import (
 	"context"
 	"net/http/httptest"
+	"net/url"
 	"testing"
 
 	"github.com/go-acme/lego/v4/platform/tester/servermock"
@@ -12,7 +13,7 @@ import (
 
 func setupIdentifierClient(server *httptest.Server) (*Identifier, error) {
 	client := NewIdentifier("user", "secret")
-	client.authEndpoint = server.URL
+	client.BaseURL, _ = url.Parse(server.URL)
 	client.HTTPClient = server.Client()
 
 	return client, nil
@@ -26,10 +27,13 @@ func mockContext(t *testing.T) context.Context {
 
 func TestIdentifier_Authentication(t *testing.T) {
 	client := servermock.NewBuilder[*Identifier](setupIdentifierClient).
-		Route("POST /", servermock.ResponseFromFixture("auth.xml")).
+		Route("POST /KasAuth.php",
+			servermock.ResponseFromFixture("auth.xml"),
+			servermock.CheckRequestBodyFromFixture("auth-request.xml").
+				IgnoreWhitespace()).
 		Build(t)
 
-	credentialToken, err := client.Authentication(t.Context(), 60, false)
+	credentialToken, err := client.Authentication(t.Context(), 60, true)
 	require.NoError(t, err)
 
 	assert.Equal(t, "593959ca04f0de9689b586c6a647d15d", credentialToken)
@@ -37,7 +41,7 @@ func TestIdentifier_Authentication(t *testing.T) {
 
 func TestIdentifier_Authentication_error(t *testing.T) {
 	client := servermock.NewBuilder[*Identifier](setupIdentifierClient).
-		Route("POST /", servermock.ResponseFromFixture("auth_fault.xml")).
+		Route("POST /KasAuth.php", servermock.ResponseFromFixture("auth_fault.xml")).
 		Build(t)
 
 	_, err := client.Authentication(t.Context(), 60, false)
