@@ -4,6 +4,7 @@ import (
 	"bytes"
 	"encoding/xml"
 	"fmt"
+	"io"
 )
 
 // Trimmer trim all XML fields.
@@ -16,6 +17,7 @@ func (tr Trimmer) Token() (xml.Token, error) {
 	if cd, ok := t.(xml.CharData); ok {
 		t = xml.CharData(bytes.TrimSpace(cd))
 	}
+
 	return t, err
 }
 
@@ -24,10 +26,11 @@ type Fault struct {
 	Code    string `xml:"faultcode"`
 	Message string `xml:"faultstring"`
 	Actor   string `xml:"faultactor"`
+	Detail  string `xml:"detail"`
 }
 
-func (f Fault) Error() string {
-	return fmt.Sprintf("%s: %s: %s", f.Actor, f.Code, f.Message)
+func (f *Fault) Error() string {
+	return fmt.Sprintf("%s: %s: %s: %s", f.Actor, f.Code, f.Message, f.Detail)
 }
 
 // KasResponse a KAS SOAP response.
@@ -44,3 +47,19 @@ type Item struct {
 	Value *Item   `xml:"value" json:"value,omitempty"`
 	Items []*Item `xml:"item" json:"item,omitempty"`
 }
+
+func decodeXML[T any](reader io.Reader) (*T, error) {
+	raw, err := io.ReadAll(reader)
+	if err != nil {
+		return nil, fmt.Errorf("read response body: %w", err)
+	}
+
+	var result T
+
+	err = xml.NewTokenDecoder(Trimmer{decoder: xml.NewDecoder(bytes.NewReader(raw))}).Decode(&result)
+	if err != nil {
+		return nil, fmt.Errorf("decode XML response: %w", err)
+	}
+
+	return &result, nil
+}
