@@ -6,12 +6,12 @@ import (
 	"errors"
 	"fmt"
 	"net/http"
-	"sync"
 	"time"
 
 	"github.com/aziontech/azionapi-go-sdk/idns"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
+	"github.com/go-acme/lego/v4/providers/dns/internal/clientdebug"
 )
 
 // Environment variables names.
@@ -55,9 +55,6 @@ func NewDefaultConfig() *Config {
 type DNSProvider struct {
 	config *Config
 	client *idns.APIClient
-
-	recordIDs   map[string]int32
-	recordIDsMu sync.Mutex
 }
 
 // NewDNSProvider returns a DNSProvider instance configured for Azion.
@@ -92,12 +89,13 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 		clientConfig.HTTPClient = config.HTTPClient
 	}
 
+	clientConfig.HTTPClient = clientdebug.Wrap(clientConfig.HTTPClient)
+
 	client := idns.NewAPIClient(clientConfig)
 
 	return &DNSProvider{
-		config:    config,
-		client:    client,
-		recordIDs: make(map[string]int32),
+		config: config,
+		client: client,
 	}, nil
 }
 
@@ -134,6 +132,7 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 	record.SetTtl(int32(d.config.TTL))
 
 	var resp *idns.PostOrPutRecordResponse
+
 	if existingRecord != nil {
 		// Update existing record by adding the new value to the existing ones
 		record.SetAnswersList(append(existingRecord.GetAnswersList(), info.Value))
@@ -157,11 +156,6 @@ func (d *DNSProvider) Present(domain, token, keyAuth string) error {
 		return errors.New("azion: create zone record error")
 	}
 
-	results := resp.GetResults()
-	d.recordIDsMu.Lock()
-	d.recordIDs[token] = results.GetId()
-	d.recordIDsMu.Unlock()
-
 	return nil
 }
 
@@ -181,13 +175,6 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 		return fmt.Errorf("azion: %w", err)
 	}
 
-	defer func() {
-		// Cleans the record ID.
-		d.recordIDsMu.Lock()
-		delete(d.recordIDs, token)
-		d.recordIDsMu.Unlock()
-	}()
-
 	existingRecord, err := d.findExistingTXTRecord(ctxAuth, zone.GetId(), subDomain)
 	if err != nil {
 		return fmt.Errorf("azion: find existing record: %w", err)
@@ -200,6 +187,7 @@ func (d *DNSProvider) CleanUp(domain, token, keyAuth string) error {
 	currentAnswers := existingRecord.GetAnswersList()
 
 	var updatedAnswers []string
+
 	for _, answer := range currentAnswers {
 		if answer != info.Value {
 			updatedAnswers = append(updatedAnswers, answer)
