@@ -14,9 +14,12 @@ import (
 	"github.com/go-acme/lego/v4/challenge"
 	"github.com/go-acme/lego/v4/challenge/dns01"
 	"github.com/go-acme/lego/v4/platform/config/env"
-	ycdns "github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1"
-	ycsdk "github.com/yandex-cloud/go-sdk"
-	"github.com/yandex-cloud/go-sdk/iamkey"
+	ycdnsproto "github.com/yandex-cloud/go-genproto/yandex/cloud/dns/v1"
+	ycdns "github.com/yandex-cloud/go-sdk/services/dns/v1"
+	ycsdk "github.com/yandex-cloud/go-sdk/v2"
+	"github.com/yandex-cloud/go-sdk/v2/credentials"
+	"github.com/yandex-cloud/go-sdk/v2/pkg/iamkey"
+	"github.com/yandex-cloud/go-sdk/v2/pkg/options"
 )
 
 // Environment variables names.
@@ -54,7 +57,7 @@ func NewDefaultConfig() *Config {
 
 // DNSProvider implements the challenge.Provider interface.
 type DNSProvider struct {
-	client *ycsdk.SDK
+	client ycdns.DnsZoneClient
 	config *Config
 }
 
@@ -91,19 +94,19 @@ func NewDNSProviderConfig(config *Config) (*DNSProvider, error) {
 		return nil, fmt.Errorf("yandexcloud: iam token is malformed: %w", err)
 	}
 
-	client, err := ycsdk.Build(context.Background(), ycsdk.Config{Credentials: creds})
+	sdk, err := ycsdk.Build(context.Background(), options.WithCredentials(creds))
 	if err != nil {
 		return nil, errors.New("yandexcloud: unable to build yandex cloud sdk")
 	}
 
 	return &DNSProvider{
-		client: client,
+		client: ycdns.NewDnsZoneClient(sdk),
 		config: config,
 	}, nil
 }
 
 // Present creates a TXT record to fulfill the dns-01 challenge.
-func (r *DNSProvider) Present(domain, _, keyAuth string) error {
+func (d *DNSProvider) Present(domain, _, keyAuth string) error {
 	info := dns01.GetChallengeInfo(domain, keyAuth)
 
 	authZone, err := dns01.FindZoneByFqdn(info.EffectiveFQDN)
@@ -113,7 +116,7 @@ func (r *DNSProvider) Present(domain, _, keyAuth string) error {
 
 	ctx := context.Background()
 
-	zones, err := r.getZones(ctx)
+	zones, err := d.getZones(ctx)
 	if err != nil {
 		return fmt.Errorf("yandexcloud: %w", err)
 	}
@@ -135,7 +138,7 @@ func (r *DNSProvider) Present(domain, _, keyAuth string) error {
 		return fmt.Errorf("yandexcloud: %w", err)
 	}
 
-	err = r.upsertRecordSetData(ctx, zoneID, subDomain, info.Value)
+	err = d.upsertRecordSetData(ctx, zoneID, subDomain, info.Value)
 	if err != nil {
 		return fmt.Errorf("yandexcloud: %w", err)
 	}
@@ -144,7 +147,7 @@ func (r *DNSProvider) Present(domain, _, keyAuth string) error {
 }
 
 // CleanUp removes the TXT record matching the specified parameters.
-func (r *DNSProvider) CleanUp(domain, _, keyAuth string) error {
+func (d *DNSProvider) CleanUp(domain, _, keyAuth string) error {
 	info := dns01.GetChallengeInfo(domain, keyAuth)
 
 	authZone, err := dns01.FindZoneByFqdn(info.EffectiveFQDN)
@@ -154,7 +157,7 @@ func (r *DNSProvider) CleanUp(domain, _, keyAuth string) error {
 
 	ctx := context.Background()
 
-	zones, err := r.getZones(ctx)
+	zones, err := d.getZones(ctx)
 	if err != nil {
 		return fmt.Errorf("yandexcloud: %w", err)
 	}
@@ -176,7 +179,7 @@ func (r *DNSProvider) CleanUp(domain, _, keyAuth string) error {
 		return fmt.Errorf("yandexcloud: %w", err)
 	}
 
-	err = r.removeRecordSetData(ctx, zoneID, subDomain, info.Value)
+	err = d.removeRecordSetData(ctx, zoneID, subDomain, info.Value)
 	if err != nil {
 		return fmt.Errorf("yandexcloud: %w", err)
 	}
@@ -186,17 +189,17 @@ func (r *DNSProvider) CleanUp(domain, _, keyAuth string) error {
 
 // Timeout returns the timeout and interval to use when checking for DNS propagation.
 // Adjusting here to cope with spikes in propagation times.
-func (r *DNSProvider) Timeout() (timeout, interval time.Duration) {
-	return r.config.PropagationTimeout, r.config.PollingInterval
+func (d *DNSProvider) Timeout() (timeout, interval time.Duration) {
+	return d.config.PropagationTimeout, d.config.PollingInterval
 }
 
 // getZones retrieves available zones from yandex cloud.
-func (r *DNSProvider) getZones(ctx context.Context) ([]*ycdns.DnsZone, error) {
-	list := &ycdns.ListDnsZonesRequest{
-		FolderId: r.config.FolderID,
+func (d *DNSProvider) getZones(ctx context.Context) ([]*ycdnsproto.DnsZone, error) {
+	list := &ycdnsproto.ListDnsZonesRequest{
+		FolderId: d.config.FolderID,
 	}
 
-	response, err := r.client.DNS().DnsZone().List(ctx, list)
+	response, err := d.client.List(ctx, list)
 	if err != nil {
 		return nil, errors.New("unable to fetch dns zones")
 	}
@@ -204,28 +207,29 @@ func (r *DNSProvider) getZones(ctx context.Context) ([]*ycdns.DnsZone, error) {
 	return response.GetDnsZones(), nil
 }
 
-func (r *DNSProvider) upsertRecordSetData(ctx context.Context, zoneID, name, value string) error {
-	get := &ycdns.GetDnsZoneRecordSetRequest{
+func (d *DNSProvider) upsertRecordSetData(ctx context.Context, zoneID, name, value string) error {
+	get := &ycdnsproto.GetDnsZoneRecordSetRequest{
 		DnsZoneId: zoneID,
 		Name:      name,
 		Type:      "TXT",
 	}
 
-	exist, err := r.client.DNS().DnsZone().GetRecordSet(ctx, get)
+	exist, err := d.client.GetRecordSet(ctx, get)
 	if err != nil {
 		if !strings.Contains(err.Error(), "RecordSet not found") {
 			return err
 		}
 	}
 
-	record := &ycdns.RecordSet{
+	record := &ycdnsproto.RecordSet{
 		Name: name,
 		Type: "TXT",
-		Ttl:  int64(r.config.TTL),
+		Ttl:  int64(d.config.TTL),
 		Data: []string{},
 	}
 
-	var deletions []*ycdns.RecordSet
+	var deletions []*ycdnsproto.RecordSet
+
 	if exist != nil {
 		record.SetData(append(record.GetData(), exist.GetData()...))
 		deletions = append(deletions, exist)
@@ -237,25 +241,25 @@ func (r *DNSProvider) upsertRecordSetData(ctx context.Context, zoneID, name, val
 		return nil
 	}
 
-	update := &ycdns.UpdateRecordSetsRequest{
+	update := &ycdnsproto.UpdateRecordSetsRequest{
 		DnsZoneId: zoneID,
 		Deletions: deletions,
-		Additions: []*ycdns.RecordSet{record},
+		Additions: []*ycdnsproto.RecordSet{record},
 	}
 
-	_, err = r.client.DNS().DnsZone().UpdateRecordSets(ctx, update)
+	_, err = d.client.UpdateRecordSets(ctx, update)
 
 	return err
 }
 
-func (r *DNSProvider) removeRecordSetData(ctx context.Context, zoneID, name, value string) error {
-	get := &ycdns.GetDnsZoneRecordSetRequest{
+func (d *DNSProvider) removeRecordSetData(ctx context.Context, zoneID, name, value string) error {
+	get := &ycdnsproto.GetDnsZoneRecordSetRequest{
 		DnsZoneId: zoneID,
 		Name:      name,
 		Type:      "TXT",
 	}
 
-	previousRecord, err := r.client.DNS().DnsZone().GetRecordSet(ctx, get)
+	previousRecord, err := d.client.GetRecordSet(ctx, get)
 	if err != nil {
 		if strings.Contains(err.Error(), "RecordSet not found") {
 			// RecordSet is not present, nothing to do
@@ -265,14 +269,14 @@ func (r *DNSProvider) removeRecordSetData(ctx context.Context, zoneID, name, val
 		return err
 	}
 
-	var additions []*ycdns.RecordSet
+	var additions []*ycdnsproto.RecordSet
 
 	if len(previousRecord.GetData()) > 1 {
 		// RecordSet is not empty we should update it
-		record := &ycdns.RecordSet{
+		record := &ycdnsproto.RecordSet{
 			Name: name,
 			Type: "TXT",
-			Ttl:  int64(r.config.TTL),
+			Ttl:  int64(d.config.TTL),
 			Data: []string{},
 		}
 
@@ -285,34 +289,35 @@ func (r *DNSProvider) removeRecordSetData(ctx context.Context, zoneID, name, val
 		additions = append(additions, record)
 	}
 
-	update := &ycdns.UpdateRecordSetsRequest{
+	update := &ycdnsproto.UpdateRecordSetsRequest{
 		DnsZoneId: zoneID,
-		Deletions: []*ycdns.RecordSet{previousRecord},
+		Deletions: []*ycdnsproto.RecordSet{previousRecord},
 		Additions: additions,
 	}
 
-	_, err = r.client.DNS().DnsZone().UpdateRecordSets(ctx, update)
+	_, err = d.client.UpdateRecordSets(ctx, update)
 
 	return err
 }
 
 // decodeCredentials converts base64 encoded json of iam token to struct.
-func decodeCredentials(accountB64 string) (ycsdk.Credentials, error) {
+func decodeCredentials(accountB64 string) (credentials.Credentials, error) {
 	account, err := base64.StdEncoding.DecodeString(accountB64)
 	if err != nil {
 		return nil, err
 	}
 
 	key := &iamkey.Key{}
+
 	err = json.Unmarshal(account, key)
 	if err != nil {
 		return nil, err
 	}
 
-	return ycsdk.ServiceAccountKey(key)
+	return credentials.ServiceAccountKey(key)
 }
 
-func appendRecordSetData(record *ycdns.RecordSet, value string) bool {
+func appendRecordSetData(record *ycdnsproto.RecordSet, value string) bool {
 	if slices.Contains(record.GetData(), value) {
 		return false
 	}
